@@ -1,5 +1,6 @@
 package Mojolicious::Plugin::AssetPack::Pipe::Css;
 use Mojo::Base 'Mojolicious::Plugin::AssetPack::Pipe';
+
 use Mojolicious::Plugin::AssetPack::Util qw(diag load_module DEBUG);
 
 sub process {
@@ -8,20 +9,18 @@ sub process {
   my $file;
 
   return unless $self->assetpack->minify;
-  return $assets->each(
-    sub {
-      my ($asset, $index) = @_;
-      my $attrs = $asset->TO_JSON;
-      $attrs->{key}      = 'css-min';
-      $attrs->{minified} = 1;
-      return if $asset->format ne 'css' or $asset->minified;
-      return $asset->content($file)->minified(1) if $file = $store->load($attrs);
-      load_module 'CSS::Minifier::XS';
-      diag 'Minify "%s" with checksum %s.', $asset->url, $asset->checksum if DEBUG;
-      my $css = CSS::Minifier::XS::minify($asset->content);
-      $asset->content($store->save(\$css, $attrs))->minified(1);
-    }
-  );
+  return $assets->each(sub {
+    my ($asset, $index) = @_;
+    my $attrs = $asset->TO_JSON;
+    $attrs->{key}      = 'css-min';
+    $attrs->{minified} = 1;
+    return if $asset->format ne 'css' or $asset->minified;
+    return $asset->content($file)->minified(1) if $file = $store->load($attrs);
+    load_module 'CSS::Minifier::XS';
+    diag 'Minify "%s" with checksum %s.', $asset->url, $asset->checksum if DEBUG;
+    my $css = CSS::Minifier::XS::minify($asset->content);
+    $asset->content($store->save(\$css, $attrs))->minified(1);
+  });
 }
 
 1;
